## PYME Profile Viewer

Usage

The profile viewer allows us to visualize multi-threaded call traces made using the fProfile module. Before viewing, these traces must be converted from their original raw .txt output to a .json format that has re-built the call tree. This is accomplished by using the convertProfile.py script

- Each line represents the activity of a single thread
- The top condensed rows show an overview the entire process duration. Selecting a region/ "brush" in these rows restricts the time window of the low, detail views. Make this selection by dragging with the mouse within the upper rows.
- Each block corresponds to a single function call. Hovering over a block shows the method name and the source file it is defined in. NOTE: only those method calls matching the regex used when running fProfile are shown.

Please specify the .json formatted profile file to use